[][src]Module x509_parser::objects

X.509 helper objects definitions: OID, short and long names, NID (internal ID)

Most definitions taken from OpenSSL: /usr/include/openssl/objects.h Note: values does not match openssl, for ex. NIDs

Note: the objects registry is implemented as a static array with linear search. This is not the most efficient method, but makes maintainance easier.

Enums

Nid

ASN.1 node internal identifier

Constants

OID_ALGO
OID_C
OID_CN
OID_EMAIL
OID_EXT_AKI
OID_EXT_AUTHORITYKEYIDENTIFIER
OID_EXT_BASICCONSTRAINTS
OID_EXT_BC
OID_EXT_CERTIFICATEPOLICIES
OID_EXT_CPOL
OID_EXT_EKU
OID_EXT_EXTENDEDKEYUSAGE
OID_EXT_INHIBITANYPOLICY
OID_EXT_KEYUSAGE
OID_EXT_KU
OID_EXT_NAMECONSTRAINTS
OID_EXT_PKUP
OID_EXT_POLICYCONSTRAINTS
OID_EXT_POLICYMAPPINGS
OID_EXT_PRIVATEKEYUSAGEPERIOD
OID_EXT_SAN
OID_EXT_SKI
OID_EXT_SUBJECTALTNAME
OID_EXT_SUBJECTKEYIDENTIFIER
OID_L
OID_O
OID_OU
OID_PKCS9
OID_RSADSI
OID_RSAENCRYPTION
OID_RSASHA1
OID_ST
OID_X500
OID_X509

Functions

nid2sn

Returns the short name corresponding to the Nid

nid2ln

Returns the long name corresponding to the Nid

nid2obj
oid2nid
oid2sn

Returns the short name corresponding to the OID

sn2oid

Given a short name, returns the matching OID